#
# spec file for package ThePEG
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# DISABLE JAVA BINDINGS UNTIL COMPATIBLE WITH openjdk >= 1.9
%bcond_with java

%define sonum 30

Name:           ThePEG
Version:        2.3.0
Release:        1.5
Summary:        Toolkit providing a common platform for event generators in C++
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://herwig.hepforge.org/
Source:         https://thepeg.hepforge.org/downloads/%{name}-%{version}.tar.bz2
BuildRequires:  HepMC-devel
BuildRequires:  LHAPDF-devel
BuildRequires:  Rivet-devel
BuildRequires:  YODA-devel
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gsl-devel
BuildRequires:  libboost_test-devel
%if %{with java}
BuildRequires:  java-devel
%endif
BuildRequires:  time
BuildRequires:  pkgconfig(zlib)
# 32-BIT BUILDS ARE NOT SUPPORTED BY UPSTREAM
ExcludeArch:    %{ix86} %{arm}

%description
ThePEG project is a toolkit for providing a common platform for using and
building event generators in C++.

%package -n libThePEG%{sonum}
Summary:        Toolkit providing a common platform for event generators in C++
Group:          System/Libraries
Obsoletes:      ThePEG-libs < 2.3.0

%description -n libThePEG%{sonum}
ThePEG project is a toolkit for providing a common platform for using and
building event generators in C++.

This package provides the shared libraries for ThePEG.

%package devel
Summary:        Toolkit providing a common platform for event generators in C++
Group:          Development/Libraries/C and C++
Requires:       libThePEG%{sonum} = %{version}

%description devel
ThePEG project is a toolkit for providing a common platform for using and
building event generators in C++.

This package provides the header and source files needed for development with
ThePEG.

%prep
%setup -q

# FIX AN env BASED HASHBANG
sed -i "1{s|#! /usr/bin/env bash|#!/bin/bash|}" ./src/thepeg-config.in

%build
%configure \
  --with-hepmcversion=3 \
  --with-rivet=%{_prefix}
%make_build

%install
%make_install
mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
cat << EOF > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}%{sonum}.conf
%{_libdir}/%{name}
EOF

find %{buildroot}%{_libdir}/%{name} -name "*.la" -delete -print
%fdupes -s %{buildroot}%{_libdir}/%{name}/

%post   -n libThePEG%{sonum} -p /sbin/ldconfig
%postun -n libThePEG%{sonum} -p /sbin/ldconfig

%check
%make_build check

%files -n libThePEG%{sonum}
%doc AUTHORS GUIDELINES ChangeLog NEWS README
%license COPYING
%config %{_sysconfdir}/ld.so.conf.d/%{name}%{sonum}.conf
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so.%{sonum}*

%files devel
%{_bindir}/runThePEG
%{_bindir}/setupThePEG
%{_bindir}/thepeg-config
%{_includedir}/%{name}/
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/Makefile
%{_libdir}/%{name}/Makefile.common
%{_libdir}/%{name}/ThePEGDefaults-%{version}.rpo
%{_libdir}/%{name}/ThePEGDefaults.rpo
%{_libdir}/%{name}/runThePEG-%{version}
%{_libdir}/%{name}/setupThePEG-%{version}
%{_datadir}/%{name}/
%if %{with java}
%{_bindir}/thepeg
%{_libdir}/%{name}/ThePEG.jar
%endif

%changelog
* Wed Jan  3 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.3.0:
  * gcc-12/c++17/c++20 compatibility added
  * hepmc3 compatibility added
  * rivet interface improved
  * infrastructure for dark interaction added
- Remove no longer required ThePEG_gcc6_failed.patch
- Run test suite.
- Add 32-bit ARM to ExcludeArch.
- Follow shared lib packaging policy by renaming ThePEG-libs to
  libThePEG* and using a versioned ld.so.conf file.
* Mon May  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.3:
  * Support for spin 3 particles added.
  * hepmc3 compatiblity added.
  * Various bug fixes and improvements.
  * Fix for c++11 compatiblity added.
* Thu Mar 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.2:
  * Add meta mechanism to event record.
  * Add option of preloading yoda files and remove support for
    rivet-1 and aida.
* Tue Jul 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.1:
  * New release solely to keep Herwig and ThePEG version numbers
    in sync.
- Pass `with-hepmcversion=3` and `with-rivet=%%{_prefix}` to
  configure fix ThePEG not compiling with HepMC and Rivet support.
- Drop conditionals for old openSUSE versions.
- Fix an env based hashbang.
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.0:
  * Improvements to the unit templates, building with gcc 4.8 is
    no longer possible
  * Several smaller bug fixes and additions, to allow new features
    in Herwig 7.2
- Changes from version 2.1.6:
  * Update boost.m4 to allow compliation with new boost versions
  * Increase the eps parameter for boosts of wavefunctions
  * Fixes for gcc4.8 and C++17
  * Added inelasticity cut in SimpleDISCut
- Use %%license to package COPYING file.
- Disable i586 arch: not supported by upstream.
* Thu May  2 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.5
  * Improvements to template instantation of templates with gcc9
    and icc T23
  * Change in assignment operator definition, add delete, to avoid
    warnings with gcc9
  * Minor changes for compilation with gcc8,9, icc and clang
- Changes from version 2.1.4:
  * Improvements to helicity libraries to support more BSM models
  * Added FixedTargetLuminosity for fixed target collisions
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2.1.3:
  * Use std::array<> where suitable
* Thu Nov  2 2017 badshah400@gmail.com
- Update to version 2.1.2:
  * Allow LHAPDF6 interface to return photon pdf.
  * Sign fix in GeneralVVSVertex
  * Fix multiple weight reading from LHE files
  * Preparations for Rivet 3
* Sat Sep 23 2017 badshah400@gmail.com
- Disable java bindings and binary until ThePEG becomes
  compatible with openjdk >= 1.9; fixes build failures in Factory.
* Sat Sep  2 2017 badshah400@gmail.com
- Build with HepMC2-devel, since Rivet does not compile with
  HepMC-devel >= 3 yet.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 2.1.1:
  * Added missing evaluate() option to GeneralVVSVertex
  * More robust reading of LHE files
  * Warn about duplicate PDG names in user input
  * Write current timestamp into log files
  * Calling 'read' in an input file will no longer change the
    repository directory you're in
- Changes from version 2.1.0:
  * Transition to C++-11 code, building with C++-98 is no longer
    possible
  * Interfaces with two choices now consistently accept Yes/No as
    answer
  * Several smaller bug fixes and additions, to allow new features
    in Herwig 7.1
- Refresh ThePEG_gcc6_failed.patch for updated version.
* Mon Feb 13 2017 jengelh@inai.de
- Rename from libThePEG24 to ThePEG-libs as the package does not
  satisfy the SLPP guideline: there are a number of non-.so.24
  files.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 2.0.4:
  * Default weight explicitly labelled: The nominal event weight
    is now labelled "Default" and is always the first weight to be
    inserted into HepMC.
  * LesHouches event weights handling: There are now two options
    for the treatment of optional weights coming in from a Les
    Houches file, available through
    "LesHouchesEventHandler:WeightNormalization". Either they are
    normalized to the "Default" weight ("Normalized"), or they are
    given as cross-sections in pb ("CrossSection"). The default
    behaviour is "Normalized".
  * JetFinder in Cuts objects writes information: The selected
    JetFinder is explicitly listed in the debug output.
- Lots of changes from version 1.9.2 (last packaged) through
  v2.0.3; please see NEWS file for details.
- Add java-devel BuildRequires; required to build new GUI.
- Add YODA-devel BuildRequires; required for configuring Rivet
  during build.
* Sun Jun 19 2016 jengelh@inai.de
- RPM group classification and direct use of ldconfig
* Thu Jun 16 2016 normand@linux.vnet.ibm.com
- new ThePEG_gcc6_failed.patch to avoid gcc6 build failure
  tracked upstream by
  https://herwig.hepforge.org/trac/ticket/4
* Thu Sep  4 2014 badshah400@gmail.com
- Update to version 1.9.2:
  + Better support for LHAPDF 6; now determines if version 6 is
    available and makes use of new LHAPDFv6 features
- Changes from version 1.9.1:
  + Build fix for SLC6
  + Build fix for Rivet 2.1.1: adapted to Rivet 2.1.1 changed
    header file layout
- Use macro instead of hard-coding version in file-list.
* Sat Dec  7 2013 badshah400@gmail.com
- Initial version
